adviseable_parse2_call

Function adviseable_parse2_call 

pub fn adviseable_parse2_call<T>(
    input: TokenStream,
    call: impl FnOnce(ParseStream<'_>) -> Result<AdviseableInnerResult<T>>,
) -> Result<T>
Parses with a callback, and produces advice if necessary

Version of adviseable_parse2 that takes a callback function, rather than a trait impl.